You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@harmony.apache.org by dl...@apache.org on 2006/06/30 15:46:55 UTC

svn commit: r418282 - /incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/class.c

Author: dlydick
Date: Fri Jun 30 06:46:54 2006
New Revision: 418282

URL: http://svn.apache.org/viewvc?rev=418282&view=rev
Log:
Notes in commented-out section on future
function class_load_from_cp_entry_class()

Modified:
    incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/class.c

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/class.c
URL: http://svn.apache.org/viewvc/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/class.c?rev=418282&r1=418281&r2=418282&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/class.c (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/class.c Fri Jun 30 06:46:54 2006
@@ -1007,11 +1007,10 @@
  * @name DEFAULT SYSTEM CLASS LOADER:
  *
  * @brief perform the duties of @c @b java.lang.ClassLoader
-
  * Using either null-terminated strings or UTF strings from
  * @link #CONSTANT_Utf8_info CONSTANT_Utf8_info@endlink or
  * @link #CONSTANT_Class_info CONSTANT_Class_info@endlink
- * @c @b constant_pool entries, the following three functions function
+ * @c @b constant_pool entries, the following three functions act
  * as the system default class loader that can be invoked three
  * different ways.  It searches @b CLASSPATH, reads in a class
  * file, parses its contents, and loads it into the class table
@@ -1421,17 +1420,14 @@
 /*NOTREACHED*/
     }
 
-    rchar *prchar_clsname =
-        utf_utf2prchar(
-            PTR_THIS_CP_Utf8(
-                &pcfs->constant_pool
-                 [PTR_THIS_CP_Class(clsname)->name_index]));
-
-    jvm_class_index clsidx = class_load_from_prchar(prchar_clsname,
-                                                   find_registerNatives,
-                                                    arraylength);
+    cp_info_mem_align *cp_clsname = XXX_XXXXXX2utf(clsname);
 
-    HEAP_FREE_DATA(prchar_clsname);
+    jvm_class_index clsidx =
+        class_load_from_cp_entry_utf(cp_clsname,
+                                     find_registerNatives,
+                                     arraylength);
+
+    HEAP_FREE_DATA(cp_clsname);
 
     return(clsidx);
 
@@ -1512,14 +1508,15 @@
  *        standard industry file naming practices, and/or (b) that
  *        no array processing happens in the lower levels.
  *
  * @todo  HARMONY-6-jvm-class.c-20 Make a version of this function
  *        that can accept a UTF8 class name, call class_load_from_utf(),
  *        and call a common function that it shares with the existing
  *        function that contains all further logic.  This will run
  *        faster than converting UTF strings to (rchar *) and calling
  *        the existing function.  This is a similar approach to what
  *        is done in @link jvm/src/thread.c thread.c@endlink to create
  *        a normal thread versus a system thread.
  *        
  *
  */
@@ -1512,14 +1508,15 @@
  *        no array processing happens in the lower levels.
  *
- * @todo  HARMONY-6-jvm-class.c-20 Make a version of this function
- *        that can accept a UTF8 class name, call class_load_from_utf(),
- *        and call a common function that it shares with the existing
- *        function that contains all further logic.  This will run
- *        faster than converting UTF strings to (rchar *) and calling
- *        the existing function.  This is a similar approach to what
- *        is done in @link jvm/src/thread.c thread.c@endlink to create
- *        a normal thread versus a system thread.
+ * @todo  HARMONY-6-jvm-class.c-20 Make a version of this
+ *        function that can accept a UTF8 class name, call
+ *        class_load_from_cp_entry_utf(), and call a common
+ *        function that it shares with the existing function
+ *        that contains all further logic.  This will run faster
+ *        than converting UTF strings to (rchar *) and calling
+ *        the existing function.  This is a similar approach to
+ *        what is done in @link jvm/src/thread.c thread.c@endlink
+ *        to create a normal thread versus a system thread.
  *        
  *